Skip to contents

An internal function to add character label columns depending on parameter type and transformation.

Usage

addEstFormat(pars, source.ci = "cov", rse.cov)

Arguments

pars

Parameter estimates (a data.frame, as generated by createParameterTable).

source.ci

Source of confidence intervals. "cov" for "Covariance step", "boot" for bootstrap, and "" for nothing.

rse.cov

Include relative standard error estimate based on covariate step? Default is TRUE if source=="cov" and FALSE if not.